@@ -11,7 +11,7 @@ type Parser struct{}
 
 // Unmarshal unmarshals HCL files that are using version 1 of
 // the HCL language.
-func (s *Parser) Unmarshal(p []byte, v interface{}) error {
+func (s *Parser) Unmarshal(p []byte, v any) error {
 	if err := hcl.Unmarshal(p, v); err != nil {
 		return fmt.Errorf("unmarshal hcl: %w", err)
 	}
