@@ -12,20 +12,20 @@ import (
 type Parser struct{}
 
 // Unmarshal unmarshals INI files.
-func (i *Parser) Unmarshal(p []byte, v interface{}) error {
+func (i *Parser) Unmarshal(p []byte, v any) error {
 	cfg, err := ini.Load(p)
 	if err != nil {
 		return fmt.Errorf("read ini file: %w", err)
 	}
 
-	result := make(map[string]map[string]interface{})
+	result := make(map[string]map[string]any)
 	for _, s := range cfg.Sections() {
 		sectionName := s.Name()
 		if sectionName == "DEFAULT" {
 			continue
 		}
 
-		result[sectionName] = map[string]interface{}{}
+		result[sectionName] = map[string]any{}
 		keysHash := s.KeysHash()
 		result[sectionName] = convertKeyTypes(keysHash)
 	}
@@ -42,8 +42,8 @@ func (i *Parser) Unmarshal(p []byte, v interface{}) error {
 	return nil
 }
 
-func convertKeyTypes(keysHash map[string]string) map[string]interface{} {
-	val := map[string]interface{}{}
+func convertKeyTypes(keysHash map[string]string) map[string]any {
+	val := map[string]any{}
 
 	for k, v := range keysHash {
 		switch {
