@@ -13,7 +13,7 @@ func TestXMLParser(t *testing.T) {
 	<body>baz</body>
 	</note>`
 
-	var input interface{}
+	var input any
 	if err := parser.Unmarshal([]byte(sample), &input); err != nil {
 		t.Fatalf("parser should not have thrown an error: %v", err)
 	}
@@ -22,9 +22,9 @@ func TestXMLParser(t *testing.T) {
 		t.Fatalf("there should be information parsed but its nil")
 	}
 
-	inputMap := input.(map[string]interface{})
+	inputMap := input.(map[string]any)
 	item := inputMap["note"]
-	if len(item.(map[string]interface{})) == 0 {
+	if len(item.(map[string]any)) == 0 {
 		t.Error("there should be at least one item defined in the parsed file, but none found")
 	}
 }
