@@ -3,6 +3,7 @@ package yaml
 import (
 	"bytes"
 	"fmt"
+	"slices"
 
 	"sigs.k8s.io/yaml"
 )
@@ -10,8 +11,14 @@ import (
 // Parser is a YAML parser.
 type Parser struct{}
 
+var (
+	lf   = []byte{'\n'}
+	crlf = []byte{'\r', '\n'}
+	sep  = []byte{'-', '-', '-'}
+)
+
 // Unmarshal unmarshals YAML files.
-func (yp *Parser) Unmarshal(p []byte, v interface{}) error {
+func (yp *Parser) Unmarshal(p []byte, v any) error {
 	subDocuments := separateSubDocuments(p)
 	if len(subDocuments) > 1 {
 		if err := unmarshalMultipleDocuments(subDocuments, v); err != nil {
@@ -29,18 +36,42 @@ func (yp *Parser) Unmarshal(p []byte, v interface{}) error {
 }
 
 func separateSubDocuments(data []byte) [][]byte {
-	linebreak := "\n"
-	if bytes.Contains(data, []byte("\r\n---\r\n")) {
-		linebreak = "\r\n"
+	// Determine line ending style
+	linebreak := lf
+	if bytes.Contains(data, crlf) {
+		linebreak = crlf
 	}
 
-	return bytes.Split(data, []byte(linebreak+"---"+linebreak))
+	separator := slices.Concat(linebreak, sep, linebreak)
+
+	// Count actual document separators
+	parts := bytes.Split(data, separator)
+
+	// If we have a directive, first part is not a separate document
+	if bytes.HasPrefix(data, []byte("%")) {
+		if len(parts) <= 2 {
+			// Single document with directive
+			return [][]byte{data}
+		}
+		// Multiple documents - combine directive with first real document
+		firstDoc := append(parts[0], append(separator, parts[1]...)...)
+		result := [][]byte{firstDoc}
+		result = append(result, parts[2:]...)
+		return result
+	}
+
+	// No directive case
+	if len(parts) <= 1 {
+		// Single document
+		return [][]byte{data}
+	}
+	return parts
 }
 
-func unmarshalMultipleDocuments(subDocuments [][]byte, v interface{}) error {
-	var documentStore []interface{}
+func unmarshalMultipleDocuments(subDocuments [][]byte, v any) error {
+	var documentStore []any
 	for _, subDocument := range subDocuments {
-		var documentObject interface{}
+		var documentObject any
 		if err := yaml.Unmarshal(subDocument, &documentObject); err != nil {
 			return fmt.Errorf("unmarshal subdocument yaml: %w", err)
 		}
